@@ -19,11 +19,12 @@
 #include <QtGui>
 
 #include "scoresheet.h"
+#include "mainwin.h"
 
 int main(int argc, char *argv[])
 {
 	QApplication app(argc, argv);
-	QWidget *win = new QWidget();
+	mainwin *win = new mainwin();
 	
 	//win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
 	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
@@ -31,6 +32,7 @@ int main(int argc, char *argv[])
 	win->setWindowTitle("Scoresheet");
 
 	CScoresheet sc(win);
+	win->setSC(&sc);
 	
 	QMenuBar *menu = new QMenuBar(win);
 	menu->addAction("Save...",&sc,SLOT(save()));
