@@ -21,6 +21,7 @@
 #include <iostream>
 #include "scoresheet.h"
 #include "csvfile.h"
+#include "mainwin.h"
 
 CScoresheet::CScoresheet(QWidget *win_)
 {
@@ -41,7 +42,10 @@ CScoresheet::CScoresheet(QWidget *win_)
 	loadingFile = false;
 	defaultName = "Player ";
 	defaultDirectory = "/home/user/MyDocs";
-	lastFileName = "scores.csv";
+	lastFileName = "";
+	sheetModified = false;
+	sheetTitle = "";
+	
 	
 	for(int i=0; i<sizeX; i++)
 	{
@@ -54,6 +58,10 @@ CScoresheet::CScoresheet(QWidget *win_)
 	QVBoxLayout *vbox = new QVBoxLayout();
 	hbox->addLayout(vbox);
 
+	title = new QLabel();
+	vbox->addWidget(title);
+	title->hide();
+
 	table = new QTableWidget(sizeY,sizeX);
 	vbox->addWidget(table);
 	table->setSelectionMode(QAbstractItemView::NoSelection);
@@ -62,8 +70,8 @@ CScoresheet::CScoresheet(QWidget *win_)
 	connect( table, SIGNAL(cellClicked(int,int)), this, SLOT(cellClicked(int,int)) );
 	vbox->setContentsMargins(0,0,0,0);
 	hbox->setContentsMargins(0,0,0,0);	
-	table->setContentsMargins(0,0,0,0);
-	
+	table->setContentsMargins(0,0,0,0);	
+
 	keys = new QWidget();
 	QGridLayout *keyslayout = new QGridLayout(keys);
 	vbox->addWidget(keys);
@@ -192,7 +200,7 @@ CScoresheet::CScoresheet(QWidget *win_)
 		QDialogButtonBox::Cancel, Qt::Vertical,dlg_confirmation);
 	confirm_hbox->addWidget(confirm_bb);
 	connect(confirm_bb, SIGNAL(accepted()), dlg_confirmation, SLOT(accept()));
-	connect(confirm_bb, SIGNAL(rejected()), dlg_confirmation, SLOT(reject()));	
+	connect(confirm_bb, SIGNAL(rejected()), dlg_confirmation, SLOT(reject()));
 
 	dlg_about = new QDialog(win,Qt::Dialog);
 	dlg_about->setWindowTitle("About");
@@ -212,6 +220,17 @@ CScoresheet::~CScoresheet()
 {
 }
 
+bool CScoresheet::close()
+{
+	if( sheetModified )
+	{
+		if( lastFileName=="" )
+			save(false);
+		else
+			save(true);
+	}
+}
+
 void CScoresheet::orientationChanged()
 {
 	QRect screenGeometry = QApplication::desktop()->screenGeometry();
@@ -261,6 +280,13 @@ void CScoresheet::updateHeaders()
 		labels << names.at(i) + "\n" + s;
 	}
 	table->setHorizontalHeaderLabels(labels);
+	
+	if( sheetTitle == "" ) {
+		title->hide();
+	} else {
+		title->setText(sheetTitle);
+		title->show();
+	}
 }
 
 
@@ -284,8 +310,11 @@ void CScoresheet::cellClicked(int row_, int col_)
 
 	typing = true;
 	table->item(lastcellRow,lastcellCol)->setSelected(true);
+	
+	sheetModified = true;
 }
 
+
 void CScoresheet::softkeyClicked()
 {
 	if( sender() )
@@ -367,9 +396,10 @@ void CScoresheet::softkeyClicked()
 
 void CScoresheet::clear()
 {
-    if( win->rect().width() < win->rect().height() )
-        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+    	if( win->rect().width() < win->rect().height() )
+        	win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
 
+	dlg_confirmation->setWindowTitle("Clear scores?");
 	if( dlg_confirmation->exec() )
 	{
 		if( table->item(lastcellRow,lastcellCol) ) {
@@ -379,6 +409,8 @@ void CScoresheet::clear()
 		
 		table->clearContents();
 		resizeTable();
+		
+		sheetModified = true;
 	}
 
 	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
@@ -406,6 +438,8 @@ void CScoresheet::showSetup()
 {
 	stp_players->setValue(sizeX);
 	stp_rows->setValue(sizeY);
+	
+	stp_title->setText( sheetTitle );
 
 	stp_list->clear();
 	stp_list->addItems(names);
@@ -430,6 +464,7 @@ void CScoresheet::saveSetup()
 	
 	sizeX = stp_players->value();
 	sizeY = stp_rows->value();
+	sheetTitle = stp_title->text();
 	
 	names.clear();
 	for(int i=0; i<sizeX; i++)
@@ -438,6 +473,7 @@ void CScoresheet::saveSetup()
 	}
 	
 	resizeTable();
+	sheetModified = true;
 }
 
 void CScoresheet::playersNumChanged(int num)
@@ -468,9 +504,17 @@ void CScoresheet::createSetup()
 	win_setup = new QDialog(win,Qt::Dialog);
 	win_setup->setWindowTitle("Scoresheet setup");
 
-	QHBoxLayout *stp_hbox0 = new QHBoxLayout(win_setup);
+	QVBoxLayout *stp_vb0 = new QVBoxLayout(win_setup);
+	QHBoxLayout *stp_hbox0 = new QHBoxLayout();
 	QVBoxLayout *stp_vbox1 = new QVBoxLayout();
 	stp_hbox0->addLayout(stp_vbox1);
+	
+	QLabel* titlelabel = new QLabel("Title:");
+	stp_title = new QLineEdit();
+	
+	stp_vb0->addWidget(titlelabel);
+	stp_vb0->addWidget(stp_title);
+	stp_vb0->addLayout(stp_hbox0);
 
 	QLabel *stp_l1 = new QLabel("Players");
 	QLabel *stp_l2 = new QLabel("Rows");
@@ -501,18 +545,31 @@ void CScoresheet::createSetup()
 	stp_hbox0->addLayout(stp_vbox2);
 	
 	connect(stp_players, SIGNAL(valueChanged(int)), this, SLOT(playersNumChanged(int)));
+	stp_list->setEditTriggers(QAbstractItemView::DoubleClicked | QAbstractItemView::SelectedClicked |
+		QAbstractItemView::AnyKeyPressed | QAbstractItemView::CurrentChanged );
 }
 
 void CScoresheet::save()
 {
+	save(false);
+}
 
-	if( win->rect().width() < win->rect().height() )
-		win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-
-	QString fname = QFileDialog::getSaveFileName(win, "Save file",
-		defaultDirectory+"/"+lastFileName, "Comma Separated Values (*.csv)");
-		
-	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+void CScoresheet::save(bool autosave)
+{
+	QString fname;
+	if( !autosave )  {
+		if( lastFileName=="" )
+			lastFileName="scores.csv";
+		if( win->rect().width() < win->rect().height() )
+			win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+		fname = QFileDialog::getSaveFileName(win, "Save file",
+			defaultDirectory+"/"+lastFileName, "Comma Separated Values (*.csv)");
+		win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+	} else {
+		if( lastFileName=="" )
+			lastFileName="scoresheet_autosave.csv";
+		fname = defaultDirectory+"/"+lastFileName;
+	}		
 
 	if( fname!=NULL && !fname.endsWith(".csv") )
 		fname.append(".csv");
@@ -525,6 +582,7 @@ void CScoresheet::save()
 		CCSVFile csv( fname );
 		
 		csv.appendRow(names);
+		csv.setDataAt(1,0,"***TITLE***"+sheetTitle);
 
 		QStringList row;		
 		for( int i=0; i<table->rowCount(); i++ )
@@ -547,12 +605,13 @@ void CScoresheet::save()
 				QMaemo5InformationBox::DefaultTimeout );
 		}
 	}
+	sheetModified = false;
 }
 
 void CScoresheet::load()
 {
-    if( win->rect().width() < win->rect().height() )
-        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+	if( win->rect().width() < win->rect().height() )
+        	win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
 
 	QString fname = QFileDialog::getOpenFileName(win, "Load file",
 		defaultDirectory, "Comma Separated Values (*.csv)");
@@ -571,8 +630,16 @@ void CScoresheet::load()
 				QMaemo5InformationBox::DefaultTimeout );
 			return;
 		}
+
+		int headerrows = 1; //the first line is for the names
+
+		if( csv.dataAt(1,0).startsWith("***TITLE***") ) {
+			sheetTitle = csv.dataAt(1,0).mid(11);
+			headerrows = 2;  // and the second for the title
+		}
+
 		sizeX = csv.columns();
-		sizeY = csv.rows()-1;  //first line is for headers
+		sizeY = csv.rows()-headerrows;  
 		if( sizeX < minSizeX ) sizeX=minSizeX;
 		if( sizeX > maxSizeX ) sizeX=maxSizeX;
 		if( sizeY < minSizeY ) sizeY=minSizeY;
@@ -588,6 +655,7 @@ void CScoresheet::load()
 			names.append(n);
 		}
 		resizeTable();
+
 		loadingFile = true;
 
 		progress->setRange(0,sizeX);
@@ -601,7 +669,7 @@ void CScoresheet::load()
 		{
 			for(int j=0; j<sizeY; j++ )
 			{
-				QString t = csv.dataAt(j+1,i);
+				QString t = csv.dataAt(j+headerrows,i);
 				if( !table->item(j,i) && t.length()>0 )
 				{
 					QTableWidgetItem *item = new QTableWidgetItem();
@@ -621,6 +689,7 @@ void CScoresheet::load()
 		loadingFile = false;		
 		updateHeaders();
 	}
+	sheetModified = false;
 }
 
 void CScoresheet::showAbout()
