@@ -30,6 +30,7 @@ class CScoresheet : public QObject
 	public:
 	CScoresheet(QWidget *win_);
 	~CScoresheet();
+	bool close();
 
 	public slots:
 	void orientationChanged();
@@ -46,6 +47,7 @@ class CScoresheet : public QObject
 
 	private:
 	
+	void save(bool autosave);
 	void createSetup();
 	void resizeTable();
 	
@@ -75,6 +77,7 @@ class CScoresheet : public QObject
 	QWidget *barV;
 	QTableWidget *table;
 	QProgressBar *progress;
+	QLabel *title;
 	
 	QDialog *win_setup;
 	QDialog *dlg_about;
@@ -83,11 +86,15 @@ class CScoresheet : public QObject
 	QSpinBox *stp_players;
 	QSpinBox *stp_rows;
 	QListWidget *stp_list;
+	QLineEdit *stp_title;
 	
 	QStringList names;
 	QList<int> totalScores;
 	
 	QString lastFileName;
+	
+	QString sheetTitle;
+	bool sheetModified;
 
 };
 
